@@ -1,6 +1,5 @@
 /*
- *	libHX/internal.h
- *	Copyright © Jan Engelhardt <jengelh [at] gmx de>, 1999 - 2008
+ *	Copyright © Jan Engelhardt <jengelh [at] medozas de>, 1999 - 2008
  *
  *	This file is part of libHX. libHX is free software; you can
  *	redistribute it and/or modify it under the terms of the GNU
@@ -10,22 +9,27 @@
 #ifndef LIBHX_INTERNAL_H
 #define LIBHX_INTERNAL_H 1
 
-#include "libHX/config.h"
-#include "libHX/defs.h"
+#include "config.h"
+#include <libHX/defs.h>
+#include <libHX/string.h>
 
 #ifdef __cplusplus
 	/* Only for our dual C/C++ testsuites */
 #	define const_cast(type, expr)       const_cast<type>(expr)
+#	define const_cast1(type, expr)      const_cast<type>(expr)
+#	define const_cast2(type, expr)      const_cast<type>(expr)
+#	define const_cast3(type, expr)      const_cast<type>(expr)
 #	define dynamic_cast(type, expr)     dynamic_cast<type>(expr)
+#	define signed_cast(type, expr)      signed_cast<type>(expr)
 #	define static_cast(type, expr)      static_cast<type>(expr)
 #	define reinterpret_cast(type, expr) reinterpret_cast<type>(expr)
 #endif
 
 #ifdef __MINGW32__
-#	include "libHX/uxcompat.h"
+#	include "uxcompat.h"
 #endif
 #ifdef _MSC_VER
-#	include "libHX/uxcompat.h"
+#	include "uxcompat.h"
 #	define snprintf _snprintf
 #endif
 
@@ -38,4 +42,6 @@
 #define MAXFNLEN 256  /* max length for filename buffer */
 #define MAXLNLEN 1024 /* max length for usual line */
 
+extern hxmc_t *HXparse_dequote_fmt(const char *, const char *, const char **);
+
 #endif /* LIBHX_INTERNAL_H */
